"use client";
import React, { useEffect, useState } from 'react';
import { useRouter, useParams, useSearchParams } from "next/navigation";
import AddPhotos from '@/components/brokerform/AddPhotos';
import LocationDetails from '@/components/brokerform/LocationDetails';
import ProjectAmenities from '@/components/brokerform/ProjectAmenities';
import ProjectDetails from '@/components/brokerform/ProjectDetails';
import NeedHelp from '@/components/postproperty/NeedHelp';
import { Score } from '@/components/postproperty/Score';
import SIdeSteps from '@/components/postproperty/SIdeSteps';
import NextBtn from '@/components/postproperty/NextBtn';
import axios from "@/services/APIservices";

const stepsContent = [
  { title: "Project Details", stepNo: 1 },
  { title: "Amenities & Price", stepNo: 2 },
  { title: "Location Details", stepNo: 3 },
  { title: "Video And Photo", stepNo: 4 }
];

const Page = () => {
  const [step, setStep] = useState(1);
  const [userData, setUserData] = useState(null);
  const [developerSubUserData, setDeveloperSubUserData] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const [submitting, setSubmitting] = useState(false);
  const params = useParams();
  const router = useRouter();
  const searchParams = useSearchParams();
  const userId = params.id;
  const postID = searchParams?.get('postID') || null;
  const subUserId = searchParams?.get('subuser') || null;

  // Project Details States
  const [projectRole, setProjectRole] = useState("Residential");
  const [projectName, setProjectName] = useState("");
  const [reraNo, setReraNo] = useState("");
  const [projectDescription, setProjectDescription] = useState("");

  // Location Details States
  const [city, setCity] = useState('');
  const [locality, setLocality] = useState('');
  const [subLocality, setSubLocality] = useState('');
  const [address, setAddress] = useState('');

  // Project Amenities States
  const [selectedAmenities, setSelectedAmenities] = useState([]);
  const [plotSize, setPlotSize] = useState('');
  const [plotSizeUnit, setPlotSizeUnit] = useState('SQ Yard');
  const [numberOfPlots, setNumberOfPlots] = useState('');
  const [pricePerUnit, setPricePerUnit] = useState('');
  const [priceUnit, setPriceUnit] = useState('SQ Yard');

  // Photos States
  const [projectPhotos, setProjectPhotos] = useState([]);
  const [projectFiles, setProjectFiles] = useState([]);
  const [youtubeLink, setYoutubeLink] = useState('');
  const [droneViewLink, setDroneViewLink] = useState('');
  const [projectMainImage, setProjectMainImage] = useState(null);

  useEffect(() => {
    const fetchUserData = async () => {
      try {
        const storedUserData = localStorage.getItem("userData");
        if (storedUserData) {
          const parsedUserData = JSON.parse(storedUserData);
          if (parsedUserData.user_id && parsedUserData.user_id != userId) {
            router.push("/");
            return;
          }

          if (subUserId && userId) {
            // Fetch sub-user details first
            const subUserResponse = await axios.get(`/api/developerSubUser-Details/${subUserId}/${userId}`);
            if (subUserResponse.data.success) {
              const subUserData = subUserResponse.data.data;
              setDeveloperSubUserData({
                name: subUserData.name,
                role: subUserData.role,
                user_id: subUserData.user_id
              });
            }

            // Then fetch main user data
            const mainUserResponse = await axios.get(`/api/dashboard/${userId}`);
            if (mainUserResponse.data.success) {
              setUserData(mainUserResponse.data.data);
            }
          } else {
            // If no sub-user, just fetch main user data
            const response = await axios.get(`/api/dashboard/${userId}`);
            if (response.data.success) {
              setUserData(response.data.data);
            }
          }
          setLoading(false);
        } else {
          router.push("/");
          return;
        }
      } catch (err) {
        console.error('Error fetching user data:', err);
        setError(err.response?.data?.message || 'Failed to load user details');
        setLoading(false);
      }
    };
    fetchUserData();
  }, [userId, subUserId, router]);

  const handleSubmit = async () => {
    try {
      setSubmitting(true);
      setError(null);

      // Validate required fields before submission
      if (!projectName || !city || !plotSize) {
        throw new Error('Please fill in all required fields');
      }

      const formData = new FormData();

      // Project Details
      formData.append('dev_project_name', projectName);
      formData.append('dev_rera_no', reraNo);
      formData.append('dev_project_land_type', projectRole);
      formData.append('dev_project_description', projectDescription);

      // Location Details
      formData.append('dev_city', city);
      formData.append('dev_locality', locality);
      formData.append('dev_sub_locality', subLocality);
      formData.append('dev_address', address);

      // Media Links
      formData.append('dev_youtube_link', youtubeLink);
      formData.append('dev_drone_view_link', droneViewLink);

      // Project Photos
      projectPhotos.forEach((photo, index) => {
        formData.append(`dev_photos[${index}]`, photo);
      });

      // Main Image
      if (projectMainImage) {
        formData.append('dev_main_image', projectMainImage);
      }

      // Amenities and Plot Details
      formData.append('dev_amenities', JSON.stringify(selectedAmenities));
      
      const plotDetails = {
        plotSize,
        plotSizeUnit,
        numberOfPlots,
        pricePerUnit,
        priceUnit
      };
      formData.append('dev_plot_details', JSON.stringify(plotDetails));

      // Add user ID and post ID if available
      if (userId) formData.append('user_id', userId);
      if (postID) formData.append('post_id', postID);
      if (subUserId) formData.append('sub_user_id', subUserId);

      // Determine API endpoint based on available parameters
      let apiEndpoint;
      if (userId && subUserId) {
        apiEndpoint = `/api/outerDeveloperSubUser/${userId}/${subUserId}`;  
      } else if (userId && postID) {
        apiEndpoint = `/api/outerDeveloper-property/${userId}/${postID}`;
      } else {
        throw new Error('Missing required parameters for API endpoint');
      }

      const response = await axios.post(apiEndpoint, formData, {
        headers: {
          'Content-Type': 'multipart/form-data',
        },
        withCredentials: true,
        timeout: 10000,
        maxRetries: 3
      });

      if (response.data.success) {
        router.push('/broker');
      } else {
        throw new Error(response.data.message || 'Submission failed');
      }
    } catch (error) {
      console.error('Error submitting form:', error);
      setError(error.message || 'Failed to submit property details. Please try again.');
      
      if (error.response?.status === 413) {
        setError('Files are too large. Please reduce the size of your uploads.');
      } else if (error.code === 'ECONNABORTED') {
        setError('Request timed out. Please check your connection and try again.');
      }
    } finally {
      setSubmitting(false);
    }
  };

  const handleNext = () => {
    if (step < 4) {
      setStep(step + 1);
    } else {
      handleSubmit();
    }
  };

  const handleBack = () => {
    if (step > 1) {
      setStep(step - 1);
    }
  };

  if (loading) {
    return (
      <div className="fixed inset-0 bg-white z-50 flex justify-center items-center">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-brand"></div>
      </div>
    );
  }

  if (error) {
    return (
      <div className="fixed inset-0 bg-white z-50 flex justify-center items-center">
        <div className="text-red-500 text-center px-4">
          {error}
        </div>
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-white">      
      <div className="container mx-auto px-4 sm:px-6 lg:px-8 py-8">
        <div className="flex flex-col lg:flex-row gap-6 lg:gap-16 justify-between">
          {/* Left Sidebar */}
          <div className="lg:w-1/4 w-full">
            <div className="sticky top-4 space-y-6">
              <SIdeSteps
                step={step}
                setStep={setStep}
                stepsContent={stepsContent}
              />
              <div className="hidden lg:block">
                <NeedHelp />
              </div>
            </div>
          </div>

          {/* Main Content */}
          <div className="lg:w-2/4 w-full">
            <div className="bg-white rounded-lg">
              {step === 1 && (
                <ProjectDetails 
                  userName={userData?.name}
                  developerSubUserName={developerSubUserData?.name}
                  developerSubUserRole={developerSubUserData?.role}
                  developerSubUserId={developerSubUserData?.user_id}
                  projectRole={projectRole}
                  setProjectRole={setProjectRole}
                  projectName={projectName}
                  setProjectName={setProjectName}
                  reraNo={reraNo}
                  setReraNo={setReraNo}
                  projectDescription={projectDescription}
                  setProjectDescription={setProjectDescription}
                />
              )}
              {step === 2 && (
                <ProjectAmenities 
                  selectedAmenities={selectedAmenities}
                  setSelectedAmenities={setSelectedAmenities}
                  plotSize={plotSize}
                  setPlotSize={setPlotSize}
                  plotSizeUnit={plotSizeUnit}
                  setPlotSizeUnit={setPlotSizeUnit}
                  numberOfPlots={numberOfPlots}
                  setNumberOfPlots={setNumberOfPlots}
                  pricePerUnit={pricePerUnit}
                  setPricePerUnit={setPricePerUnit}
                  priceUnit={priceUnit}
                  setPriceUnit={setPriceUnit}
                />
              )}
              {step === 3 && (
                <LocationDetails 
                  city={city}
                  setCity={setCity}
                  locality={locality}
                  setLocality={setLocality}
                  subLocality={subLocality}
                  setSubLocality={setSubLocality}
                  address={address}
                  setAddress={setAddress}
                />
              )}
              {step === 4 && (
                <AddPhotos 
                  projectPhotos={projectPhotos}
                  setProjectPhotos={setProjectPhotos}
                  projectFiles={projectFiles}
                  setProjectFiles={setProjectFiles}
                  youtubeLink={youtubeLink}
                  setYoutubeLink={setYoutubeLink}
                  droneViewLink={droneViewLink}
                  setDroneViewLink={setDroneViewLink}
                  projectMainImage={projectMainImage}
                  setProjectMainImage={setProjectMainImage}
                />
              )}
              
              {/* Navigation Buttons */}
              <div className="mt-6 flex flex-col sm:flex-row gap-4 justify-between">
                {step > 1 && (
                  <button
                    onClick={handleBack}
                    disabled={submitting}
                    className="w-full sm:w-auto px-6 py-3 text-sm font-medium text-gray-700 bg-gray-100 rounded-lg hover:bg-gray-200 transition-colors duration-200 disabled:opacity-50"
                  >
                    BACK
                  </button>
                )}
                <div className={`w-full ${step > 1 ? 'sm:w-auto' : ''}`}>
                  <NextBtn
                    onPress={handleNext}
                    title={step === 4 ? (submitting ? "SUBMITTING..." : "SUBMIT") : "NEXT"}
                    disabled={submitting}
                  />
                </div>
              </div>
            </div>
            <div className="lg:hidden mt-6">
              <NeedHelp />
            </div>
          </div>

          {/* Right Sidebar */}
          <div className="lg:w-1/4 w-full">
            <div className="sticky top-4">
              <Score />
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Page;